<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Web browser was not specified. Visit the configuration section</source>
        <translation>Il web browser non è stato specificato. Devi impostarlo nel panello configurazione</translation>
    </message>
    <message>
        <source>Could not spawn Web browser process. Check if the Web browser is functional</source>
        <translation>Impossibile lanciare il WEB browser.  Verificare corretta funzionalità del WEB browser</translation>
    </message>
    <message>
        <source>English</source>
        <translation>Inglese</translation>
    </message>
    <message>
        <source>Italian</source>
        <translation>Italiano</translation>
    </message>
    <message>
        <source>Polish</source>
        <translation>Polacco</translation>
    </message>
    <message>
        <source>German</source>
        <translation>Tedesco</translation>
    </message>
    <message>
        <source>Force running Kadu (not recommended).</source>
        <translation>Lanciare Kadu comunque (non raccomandato).</translation>
    </message>
    <message>
        <source>Quit.</source>
        <translation>Esci.</translation>
    </message>
    <message>
        <source>Please do not run Kadu as a root!
It&apos;s a high security risk!</source>
        <translation>Non lanciare kadu come root!
E un rischio per la sicurezza!</translation>
    </message>
    <message>
        <source>French</source>
        <translation>Francese</translation>
    </message>
    <message>
        <source>Another Kadu is running on this profile but I cannot get its process ID.</source>
        <translation>Un altra copie di Kadu funzionava ma trovare il suo process ID è impossibile.</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descrizione</translation>
    </message>
    <message>
        <source>Mark</source>
        <translation>Marco</translation>
    </message>
    <message>
        <source>Smith</source>
        <translation>Bonitta</translation>
    </message>
    <message>
        <source>Jimbo</source>
        <translation>Boni</translation>
    </message>
    <message>
        <source>Yesterday at </source>
        <translation>Yeri alle</translation>
    </message>
    <message>
        <source>dddd at </source>
        <translation>dddd alle</translation>
    </message>
    <message>
        <source>%1 weeks ago at </source>
        <translation>%1 settimane fa</translation>
    </message>
    <message>
        <source>%1 weeks and %2 days ago at </source>
        <translation>%1 settimane e %2 giorni fa</translation>
    </message>
    <message>
        <source>%1 weeks and day ago at </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>week ago at </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>week and day ago at </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>week and %2 days ago at </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>d MMMM yyyy at </source>
        <translation>d MMMM yyyy alle</translation>
    </message>
    <message>
        <source>Mail client was not specified. Visit the configuration section</source>
        <translation>Il mail client non è stato specificato. Devi impostarlo nel panello configurazione</translation>
    </message>
    <message>
        <source>Could not spawn Mail client process. Check if the Mail client is functional</source>
        <translation>Impossibile lanciare in Mail client. Verificare corretta funzionalità del Mail client</translation>
    </message>
    <message>
        <source>Look</source>
        <translation>Aspetto</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Headers and separators</source>
        <translation>Intestazioni e separatori</translation>
    </message>
    <message>
        <source>Chat header separators height</source>
        <translation>Largezza separatori intestazioni Chat</translation>
    </message>
    <message>
        <source>Message separators height</source>
        <translation>Largezza separatori intestazioni di messaggio</translation>
    </message>
    <message>
        <source>Remove chat header repetitions</source>
        <translation>Rimuovi intestazioni ripetitive nella finestra chat</translation>
    </message>
    <message>
        <source>Interval between header removal</source>
        <translation>Intervallo tra le rimozioni intestazioni</translation>
    </message>
    <message>
        <source>Server time</source>
        <translation>Il tempo da server</translation>
    </message>
    <message>
        <source>Remove server time</source>
        <translation>Rimuovi il tempo da server</translation>
    </message>
    <message>
        <source>Maximum time difference</source>
        <translation>La massima differenza del tempo</translation>
    </message>
    <message>
        <source>Window title</source>
        <translation>Titolo da finestra</translation>
    </message>
    <message>
        <source>Chat window title syntax</source>
        <translation>Sintassi della finestra Chat</translation>
    </message>
    <message>
        <source>Conference window title prefix</source>
        <translation>Prefisso del titolo della finestra di conferenza </translation>
    </message>
    <message>
        <source>Conference window title syntax</source>
        <translation>Sintassi del titolo della finestra di conferenza</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Lingua</translation>
    </message>
    <message>
        <source>Choose your language</source>
        <translation>Seleziona lingua</translation>
    </message>
    <message>
        <source>Updates</source>
        <translation>Aggiornamenti</translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation>Controlla Aggiornamenti</translation>
    </message>
    <message>
        <source>Automatically checks whether a new version is available</source>
        <translation>Automatico verifica la nuova versione</translation>
    </message>
    <message>
        <source>Applications</source>
        <translation>Programmi</translation>
    </message>
    <message>
        <source>WWW browser</source>
        <translation>WEB browser</translation>
    </message>
    <message>
        <source>Choose your browser</source>
        <translation>Seleziona WEB browser</translation>
    </message>
    <message>
        <source>Specify path</source>
        <translation>Seleziona percorso</translation>
    </message>
    <message>
        <source>Konqueror</source>
        <translation>Konqueror</translation>
    </message>
    <message>
        <source>Opera</source>
        <translation>Opera</translation>
    </message>
    <message>
        <source>Mozilla</source>
        <translation>Mozilla</translation>
    </message>
    <message>
        <source>Mozilla Firefox</source>
        <translation>Mozilla Firefox</translation>
    </message>
    <message>
        <source>Dillo</source>
        <translation>Dillo</translation>
    </message>
    <message>
        <source>Galeon</source>
        <translation>Galeon</translation>
    </message>
    <message>
        <source>Safari</source>
        <translation>Safari</translation>
    </message>
    <message>
        <source>Custom browser</source>
        <translation>WEB browser personalizzato</translation>
    </message>
    <message>
        <source>Write specific path to your browser</source>
        <translation>Specifica percorso</translation>
    </message>
    <message>
        <source>e-mail client</source>
        <translation>Email client</translation>
    </message>
    <message>
        <source>Choose your e-mail client</source>
        <translation>Seleziona il tuo Email client</translation>
    </message>
    <message>
        <source>Choose your email client</source>
        <translation>Seleziona il tuo Email client</translation>
    </message>
    <message>
        <source>KMail</source>
        <translation>KMail</translation>
    </message>
    <message>
        <source>Thunderbird</source>
        <translation>Thunderbird</translation>
    </message>
    <message>
        <source>SeaMonkey</source>
        <translation>SeaMonkey</translation>
    </message>
    <message>
        <source>Evolution</source>
        <translation>Evolution</translation>
    </message>
    <message>
        <source>Custom e-mail client</source>
        <translation>Personale Email client</translation>
    </message>
    <message>
        <source>Write specific path to your email client</source>
        <translation>Scrivo il percorso di tuo Email client</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Avanzato</translation>
    </message>
    <message>
        <source>Parser</source>
        <translation>Parser</translation>
    </message>
    <message>
        <source>Allow executing commands by parser</source>
        <translation>Permette il parser di lanciare i commands</translation>
    </message>
    <message>
        <source>Debugging</source>
        <translation>Debugging</translation>
    </message>
    <message>
        <source>Debugging mask</source>
        <translation>Màschera debug</translation>
    </message>
    <message>
        <source>Account</source>
        <translation>Conto</translation>
    </message>
    <message>
        <source>Gadu-Gadu</source>
        <translation>Gadu-Gadu</translation>
    </message>
    <message>
        <source>User data</source>
        <translation>Dati dell&apos;utente</translation>
    </message>
    <message>
        <source>UIN</source>
        <translation>Numero GG</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>Nick</source>
        <translation>Nick</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Server</translation>
    </message>
    <message>
        <source>Servers properties</source>
        <translation>Proprietà del server</translation>
    </message>
    <message>
        <source>Use default servers</source>
        <translation>Usa servers predefiniti</translation>
    </message>
    <message>
        <source>IP Addresses</source>
        <translation>Indirizzo IP</translation>
    </message>
    <message>
        <source>You can specify which GG servers to use. Separate every server using semicolon (for example: 91.197.13.26;91.197.13.24;91.197.13.29;91.197.13.6)</source>
        <translation>Scriva i indirizzi del GG servers di usare. Separare i serveri con punto e virgola (esempio: 91.197.13.26;91.197.13.24;91.197.13.29;91.197.13.6)</translation>
    </message>
    <message>
        <source>Port to connect to servers</source>
        <translation>La porta per connessione ai servers</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatico</translation>
    </message>
    <message>
        <source>8074</source>
        <translation>8074</translation>
    </message>
    <message>
        <source>443</source>
        <translation>443</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>Proxy Server</translation>
    </message>
    <message>
        <source>Use proxy server</source>
        <translation>Usa Proxy Server</translation>
    </message>
    <message>
        <source>Host</source>
        <translation>Host</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Porta</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Utente</translation>
    </message>
    <message>
        <source>Contacts</source>
        <translation>Contatti</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filtri</translation>
    </message>
    <message>
        <source>Show offline contacts</source>
        <translation>Visualizza contatti inattivi</translation>
    </message>
    <message>
        <source>Show contacts that are blocked</source>
        <translation>Visualizza contatti bloccati</translation>
    </message>
    <message>
        <source>Show contacts which are blocking me</source>
        <translation>Visualizza contatti che ti bloccano</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Anonimo</translation>
    </message>
    <message>
        <source>Ignore messages from anonymous users</source>
        <translation>Ignora i messaggi dagli utenti anonimi</translation>
    </message>
    <message>
        <source>Ignore messages from anonymous users also in conferences</source>
        <translation>Ignora i messaggi dagli utenti anonimi nella conferenza</translation>
    </message>
    <message>
        <source>Ignore richtext from anonymous users</source>
        <translation>Ignora richtext da utenti anonimi</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Private status</source>
        <translation>Solo per amici</translation>
    </message>
    <message>
        <source>When enabled, you&apos;re visible only to users on your list</source>
        <translation>Quando abilitato, sei disponibile solo per contatti nella tua lista</translation>
    </message>
    <message>
        <source>Descirption</source>
        <translation>Descrizione</translation>
    </message>
    <message>
        <source>On startup, set</source>
        <translation>Quando iniziare, utilizza</translation>
    </message>
    <message>
        <source>Choose status which will be set on startup</source>
        <translation>Seleziona il status utilizzare quando iniziare</translation>
    </message>
    <message>
        <source>Last status</source>
        <translation>L&apos;ultimo status</translation>
    </message>
    <message>
        <source>Online</source>
        <translation type="unfinished">Accessibile</translation>
    </message>
    <message>
        <source>Online (d.)</source>
        <translation type="unfinished">AAccessibile(desc)</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Occupato</translation>
    </message>
    <message>
        <source>Busy (d.)</source>
        <translation type="unfinished">Occupato (desc.)</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation>Invisibile</translation>
    </message>
    <message>
        <source>Invisible (d.)</source>
        <translation type="unfinished">Invisibile(desc.)</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Fuori linea</translation>
    </message>
    <message>
        <source>Offline (d.)</source>
        <translation type="unfinished">Fuori linea(desc)</translation>
    </message>
    <message>
        <source>On startup, set last description</source>
        <translation>Quando avviare, ispristina l&apos;ultimo status</translation>
    </message>
    <message>
        <source>Last decription will be set on startup</source>
        <translation>L&apos;ultimo status sarà utilizzare quando iniziare</translation>
    </message>
    <message>
        <source>On startup, set description</source>
        <translation>Quando iniziare utilizza il descrizione</translation>
    </message>
    <message>
        <source>Define description which will be set on startup</source>
        <translation>Scriva la descrizione utilizzata quando iniziare</translation>
    </message>
    <message>
        <source>On shutdown, keep current description</source>
        <translation>Quando spento, utilizza attuale descrizione</translation>
    </message>
    <message>
        <source>Current description will be set on shutdown</source>
        <translation>Attuale descrizione sarà utilizzare quando chiudere</translation>
    </message>
    <message>
        <source>On shutdown, set description</source>
        <translation>Quando chiudi, lascia la descrizione</translation>
    </message>
    <message>
        <source>Define description which will be set on shutdown</source>
        <translation>Scriva descrizione utilizzata quando chiudere</translation>
    </message>
    <message>
        <source>Number of kept descriptions</source>
        <translation>Numero di descrizioni ricordati</translation>
    </message>
    <message>
        <source>Allow using variables in status</source>
        <translation>Permette utilizare i variabili nel status</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Thema QT</translation>
    </message>
    <message>
        <source>Choose Qt style</source>
        <translation>Seleziona il QT Thema</translation>
    </message>
    <message>
        <source>Icon theme</source>
        <translation>Thema icone</translation>
    </message>
    <message>
        <source>Choose icon theme</source>
        <translation>Seleziona thema icone</translation>
    </message>
    <message>
        <source>Icon paths</source>
        <translation>Percorso icone</translation>
    </message>
    <message>
        <source>Definie icons paths</source>
        <translation>Percorso pre le ricerca icone</translation>
    </message>
    <message>
        <source>Show status changing button</source>
        <translation>Visualizza pulsante status</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Colori</translation>
    </message>
    <message>
        <source>Chat window</source>
        <translation>Finestra Chat</translation>
    </message>
    <message>
        <source>Text edit</source>
        <translation>Text Edit</translation>
    </message>
    <message>
        <source>My messages</source>
        <translation>Miei messaggi</translation>
    </message>
    <message>
        <source>User messages</source>
        <translation>Messaggi del contatto</translation>
    </message>
    <message>
        <source>My font</source>
        <translation>Mio carattere</translation>
    </message>
    <message>
        <source>User font</source>
        <translation>Carattere del contatto</translation>
    </message>
    <message>
        <source>My nick</source>
        <translation>Mio sopranome (nick)</translation>
    </message>
    <message>
        <source>User nick</source>
        <translation>Sopranome del contatto (nick)</translation>
    </message>
    <message>
        <source>Userbox</source>
        <translation>Userbox</translation>
    </message>
    <message>
        <source>Background</source>
        <translation>Sfondo</translation>
    </message>
    <message>
        <source>Font</source>
        <translation>Carattere</translation>
    </message>
    <message>
        <source>Descriptions font</source>
        <translation>Caratteri nel descrizione</translation>
    </message>
    <message>
        <source>Information Panel</source>
        <translation>Panello Informazione</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Caratteri</translation>
    </message>
    <message>
        <source>Font in panel</source>
        <translation>Caratteri nel panello</translation>
    </message>
    <message>
        <source>New messages notifications</source>
        <translation>Nuovi messaggi notifiche</translation>
    </message>
    <message>
        <source>Activate windows with new messages</source>
        <translation>Activa le finestre con i nuovi messaggi</translation>
    </message>
    <message>
        <source>Flash chat title on new message</source>
        <translation>Titolo finestra chat lampeggia all&apos;arrivo del nuovo messaggio</translation>
    </message>
    <message>
        <source>Show number of new messages on chat title</source>
        <translation>Visualizza in numero dei messaggi nel titolo del chat</translation>
    </message>
    <message>
        <source>Nice date format</source>
        <translation>Piacevole format del tempo</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Tema</translation>
    </message>
    <message>
        <source>Choose style of chat window</source>
        <translation>Seleziona il finestra Chat tema</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>Anteprima</translation>
    </message>
    <message>
        <source>Emoticons</source>
        <translation>Emoticons</translation>
    </message>
    <message>
        <source>Choose emoticons style</source>
        <translation>Seleziona tipo di emoticons</translation>
    </message>
    <message>
        <source>Animated</source>
        <translation>Animato</translation>
    </message>
    <message>
        <source>Static</source>
        <translation>Statico</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Senza emoticon</translation>
    </message>
    <message>
        <source>Emoticons theme</source>
        <translation>Tema emoticon</translation>
    </message>
    <message>
        <source>Choose emoticons theme</source>
        <translation>Seleziona tema emoticon</translation>
    </message>
    <message>
        <source>Emoticons paths</source>
        <translation>Percorso emoticon</translation>
    </message>
    <message>
        <source>Define emoticons paths</source>
        <translation>Scrivo il percorso del emoticon</translation>
    </message>
    <message>
        <source>Advanced...</source>
        <translation>Avvanzato...</translation>
    </message>
    <message>
        <source>Display group tabs</source>
        <translation>Visualizza gruppi</translation>
    </message>
    <message>
        <source>Displays group tabs on userbox</source>
        <translation>Visualizza gruppi al lista contatti</translation>
    </message>
    <message>
        <source>Show available contacts in bold</source>
        <translation>Contatti disponibili grassetto</translation>
    </message>
    <message>
        <source>Displays users that are not offline using a bold font</source>
        <translation>Presenta contatti che non sono ofline usare il carattere grassetto</translation>
    </message>
    <message>
        <source>Align contact icon to</source>
        <translation>Ascoia l&apos;icona di</translation>
    </message>
    <message>
        <source>Align icon next to contact name</source>
        <translation>Prima asocia l&apos;icona al nome del contatto</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Sopra</translation>
    </message>
    <message>
        <source>Center</source>
        <translation>Centro</translation>
    </message>
    <message>
        <source>Column count</source>
        <translation>Il numero di colonne</translation>
    </message>
    <message>
        <source>Number of columns displays in userbox</source>
        <translation>Il numero di colonne al lista contatti</translation>
    </message>
    <message>
        <source>Tool tip style</source>
        <translation>Tool tip tema</translation>
    </message>
    <message>
        <source>Choose userbox tool-tip style</source>
        <translation>Seleziona tool tip tema</translation>
    </message>
    <message>
        <source>Descriptions</source>
        <translation>Descrizione</translation>
    </message>
    <message>
        <source>Show descriptions</source>
        <translation>Aggiungi la descrizione</translation>
    </message>
    <message>
        <source>Displays descriptions in userbox</source>
        <translation>Aggiungi la descrizioni al lista contatti</translation>
    </message>
    <message>
        <source>Allow multiline descriptions</source>
        <translation>Permette i descrizioni multiline</translation>
    </message>
    <message>
        <source>Dislpays multiline descriptions in userbox</source>
        <translation>Permette i descrizioni multiline al lista contatti</translation>
    </message>
    <message>
        <source>Use background image</source>
        <translation>Usa imaggine sfondo</translation>
    </message>
    <message>
        <source>Background file</source>
        <translation>Immagine sfondo</translation>
    </message>
    <message>
        <source>Define background file for userbox</source>
        <translation>Specifica immaggine sfondo per lista contatti</translation>
    </message>
    <message>
        <source>Display style</source>
        <translation>Tipo di visuallizione</translation>
    </message>
    <message>
        <source>Choose userbox background style</source>
        <translation>Seleziona il tipo di sfondo</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>Piastrellato</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Centrato</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>Allungato</translation>
    </message>
    <message>
        <source>Show information panel</source>
        <translation>Visualizza panello informazioni</translation>
    </message>
    <message>
        <source>Displays information panel below userbox</source>
        <translation>Visualizza panello informazioni sotto la lista contatti</translation>
    </message>
    <message>
        <source>Show vertical scrollbar</source>
        <translation>Mostra scrollbar verticale</translation>
    </message>
    <message>
        <source>Show vertical scrollbar in information panel</source>
        <translation>Mostra scrollbar verticale nel panello</translation>
    </message>
    <message>
        <source>Show emoticons in panel</source>
        <translation>Visualizza emoticon nel panello</translation>
    </message>
    <message>
        <source>Show emoticons in information panel</source>
        <translation>Visualizza emoticon nel panello informazione</translation>
    </message>
    <message>
        <source>Choose information panel style</source>
        <translation>Seleziona panello tema</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Scorciatoie</translation>
    </message>
    <message>
        <source>Configuration</source>
        <translation>Configurazione</translation>
    </message>
    <message>
        <source>Add user</source>
        <translation>Aggiungi il contatto</translation>
    </message>
    <message>
        <source>Manage modules</source>
        <translation>Gestione moduli</translation>
    </message>
    <message>
        <source>Open chat with...</source>
        <translation>Apri finestra Chat con...</translation>
    </message>
    <message>
        <source>Userlist</source>
        <translation>Lista contatti</translation>
    </message>
    <message>
        <source>Remove from userlist</source>
        <translation>Rimuovi dalla lista dei contatti</translation>
    </message>
    <message>
        <source>Search this user in directory</source>
        <translation>Cerca contatto nella cartella</translation>
    </message>
    <message>
        <source>Show / hide offline users</source>
        <translation>Visualizza/nascondi contatti inattivi</translation>
    </message>
    <message>
        <source>Show / hide users without description</source>
        <translation>Visualizza/nascondi contatti senza descrizione</translation>
    </message>
    <message>
        <source>New line / send message</source>
        <translation>Nuova line / manda messaggio</translation>
    </message>
    <message>
        <source>Clear chat</source>
        <translation>Cancella cronologia</translation>
    </message>
    <message>
        <source>Close chat</source>
        <translation>Chiudi Chat</translation>
    </message>
    <message>
        <source>Bold text</source>
        <translation>Grassetto</translation>
    </message>
    <message>
        <source>Italic text</source>
        <translation>Corsivo</translation>
    </message>
    <message>
        <source>Underline text</source>
        <translation>Sottolineato</translation>
    </message>
    <message>
        <source>Behaviour</source>
        <translation>Conservazione</translation>
    </message>
    <message>
        <source>Remember chat windows positions</source>
        <translation>Memorizza posizioni finestre chat</translation>
    </message>
    <message>
        <source>Open chat window on new message</source>
        <translation>Nuovo messaggio apre la finestra del chat</translation>
    </message>
    <message>
        <source>Open chat window when comes new message</source>
        <translation>Apre la finestra del chat quando nuovo messaggio arriva</translation>
    </message>
    <message>
        <source>Open chat window only when I&apos;m online</source>
        <translation>Apre la finestra chat solo quando sono online</translation>
    </message>
    <message>
        <source>Open chat window on new message only when online</source>
        <translation>Nuovo messaggio apre la finestra chat solo quando sono online</translation>
    </message>
    <message>
        <source>Wait for message delivery</source>
        <translation>Aspetta conferma del messagio</translation>
    </message>
    <message>
        <source>Wait for confirmation from server during send messages</source>
        <translation>Aspetta conferma del messagio quando mandare i messaggi</translation>
    </message>
    <message>
        <source>&apos;Enter&apos; in chat send message</source>
        <translation>&apos;Return&apos; manda messaggio automaticamente</translation>
    </message>
    <message>
        <source>Confirm clearing chat window</source>
        <translation>Confirmazione di cancella cronologia</translation>
    </message>
    <message>
        <source>Ask before clearing chat window</source>
        <translation>Fare la domanda prima di cancellare cronologia</translation>
    </message>
    <message>
        <source>Save opened windows on exit</source>
        <translation>Memorizza le finestre aperte quando chiudi</translation>
    </message>
    <message>
        <source>Save opened chat windows when exiting</source>
        <translation>Memorizza le finestre chat aperte quando chiudi</translation>
    </message>
    <message>
        <source>Closing</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <source>Block window close on new message</source>
        <translation>Blocca chiusura finestra con nuovo messaggio</translation>
    </message>
    <message>
        <source>Block chat window when comes new message</source>
        <translation>Blocca chiusura finestra chat quando nuovo messaggio arriva</translation>
    </message>
    <message>
        <source>Max time to block window close</source>
        <translation>Tempo massimo per blocare chiusura finestra</translation>
    </message>
    <message>
        <source>Messages</source>
        <translation>Messaggi</translation>
    </message>
    <message>
        <source>Message pruning</source>
        <translation>Limitazzionne messaggi di chat</translation>
    </message>
    <message>
        <source>Automatically prune chat messages</source>
        <translation>Limitazione automatica messaggi di chat</translation>
    </message>
    <message>
        <source>If enabled, messages are pruning</source>
        <translation>Quando abilitato i messaggi presentati sono limitati</translation>
    </message>
    <message>
        <source>Reduce the number of visible messages in chat window to</source>
        <translation>Riduci il numero di messaggi visibili a</translation>
    </message>
    <message>
        <source>Number of visible messages</source>
        <translation>Numero di messaggi visibili</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Immagini</translation>
    </message>
    <message>
        <source>Max image size</source>
        <translation>Dimensioni max. file</translation>
    </message>
    <message>
        <source>Maximum image size that we want to receive</source>
        <translation>Dimensioni maximi di file vogliamo ricevere</translation>
    </message>
    <message>
        <source>Receive images during invisibility</source>
        <translation>Ricevi immaggini mentre sei invisibile</translation>
    </message>
    <message>
        <source>Receiving images during invisibility is allowed</source>
        <translation>Ricevi immaggini mentre sei invisibile</translation>
    </message>
    <message>
        <source>Limit numbers of image recevied per minute</source>
        <translation>Limita numero di immaggini ricevuti nella minuta</translation>
    </message>
    <message>
        <source>Define limit of images received per minute</source>
        <translation>Specifica limitezza del numero di immaggini ricevuti nella minuta</translation>
    </message>
    <message>
        <source>Link folding</source>
        <translation>Arotolamento per i link</translation>
    </message>
    <message>
        <source>Automatically fold links</source>
        <translation>Arotolamento automatico per i link</translation>
    </message>
    <message>
        <source>Fold links longer than</source>
        <translation>Arotolamento automatico per i link più lunghi di</translation>
    </message>
    <message>
        <source>default</source>
        <translation>predefinito</translation>
    </message>
    <message>
        <source>Syntax: %s - status, %d - description, %i - ip, %n - nick, %a - altnick, %f - first name
%r - surname, %m - mobile, %u - uin, %g - group, %o - return _space_ if user doesn&apos;t have us in userlist
%h - gg version, %v - revDNS, %p - port, %e - email, %x - max image size
</source>
        <translation>Sintasso: %s - status, %d - descrizione, %i - indirizzo ip, %n - nick, %a - altnick, %f - nome
%r - cognome, %m - cellulare, %u - uin, %g - gruppo, %o - rende_space_quando_il_contatto_no_ha_tuo_nel_lista_contatti
%h - gg versione, %v - revDNS, %p - porta, %e - email, %x - max imaggini size</translation>
    </message>
    <message>
        <source>Syntax: %s - status, %d - description, %i - ip, %n - nick, %a - altnick, %f - first name
%r - surname, %m - mobile, %u - uin, %g - group, %o - return _space_ if user doesn&apos;t have us in userlist
%h - gg version, %v - revDNS, %p - port, %e - email, %x - max image size,
#{protocol} - protocol that triggered event,
#{event} - name of event,
</source>
        <translation>Sintasso: %s - status, %d - descrizione, %i - indirizzo ip, %n - nick, %a - altnick, %f - nome
%r - cognome, %m - cellulare, %u - uin, %g - gruppo, %o - rende_space_quando_il_contatto_no_ha_tuo_nel_lista_contatti
%h - gg versione, %v - revDNS, %p - porta, %e - email, %x - max imaggini size
#{protocol} - protocole che ha chiama event,
#{event} - nome del event,</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Proprietà</translation>
    </message>
    <message>
        <source>Opera (new tab)</source>
        <translation>Opera (nuovo tab)</translation>
    </message>
    <message>
        <source>Set invisible if last status was &apos;Offline&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Syntax: %s - status, %d - description, %i - ip, %n - nick, %a - altnick, %f - first name
%r - surname, %m - mobile, %u - uin, %g - group, %o - return _space_ if user doesn&apos;t have us in userlist
%h - gg version, %v - revDNS, %p - port, %e - email, %x - max image size,
#{message} - message content,
#{backgroundColor} - background color of message,
#{fontColor} - font color of message,
#{nickColor} - font color of nick,
#{sentDate} - when message was sent,
#{receivedDate} - when message was received,
#{separator} - separator between messages,
&lt;kadu:header&gt;text&lt;/kadu:header&gt; - text will not be displayed in &apos;Remove repeated headers&apos; mode
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start on startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically start on system startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Displays messages from anonymous users without formatting (colors, images, font weight...) Text is plain black.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display dates is nice format, like Today, Yesterday or Friday</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>About</name>
    <message>
        <source>About</source>
        <translation>Informazioni su</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <source>A&amp;uthors</source>
        <translation>A&amp;utori</translation>
    </message>
    <message>
        <source>&amp;Thanks</source>
        <translation>&amp;Ringraziamenti</translation>
    </message>
    <message>
        <source>&amp;ChangeLog</source>
        <translation>&amp;Lista Cambiamenti</translation>
    </message>
    <message>
        <source>&amp;License</source>
        <translation>&amp;Licenza</translation>
    </message>
</context>
<context>
    <name>ChatManager</name>
    <message>
        <source>%1 sends message</source>
        <translation>%1 manda messaggio</translation>
    </message>
    <message>
        <source>Clear messages in chat window</source>
        <translation>Cancella cronologia</translation>
    </message>
    <message>
        <source>Insert emoticon</source>
        <translation>Inserisci emoticon</translation>
    </message>
    <message>
        <source>Insert image</source>
        <translation>Inserisci immagine</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Grassetto</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Corsivo</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Sottolineato</translation>
    </message>
    <message>
        <source>Change color</source>
        <translation>Cambia colore</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Manda</translation>
    </message>
    <message>
        <source>Insert emoticon - enable in configuration</source>
        <translation>Inserisci Emoticon - attiva nella configurazione</translation>
    </message>
    <message>
        <source>&amp;Chat</source>
        <translation>&amp;Chat</translation>
    </message>
    <message>
        <source>Search this user in directory</source>
        <translation>Cerca contatto nella cartella</translation>
    </message>
    <message>
        <source>Ignore user</source>
        <translation>Ignora contatto</translation>
    </message>
    <message>
        <source>Block user</source>
        <translation>Blocca contatto</translation>
    </message>
    <message>
        <source>Anonymous users will be unblocked after restarting Kadu</source>
        <translation>Contatti anonimi saranno unbloccati dopo il restart di Kadu</translation>
    </message>
    <message>
        <source>Open chat with...</source>
        <translation>Apri finestra di Chat con...</translation>
    </message>
</context>
<context>
    <name>ChatWidget</name>
    <message>
        <source>Leave conference</source>
        <translation>Esci la conferenza</translation>
    </message>
    <message>
        <source>Insert image</source>
        <translation>Inserisci immagine</translation>
    </message>
    <message>
        <source>This file is not readable</source>
        <translation>Questo file non è leggibile</translation>
    </message>
    <message>
        <source>This file is too big (%1 &gt;= %2)</source>
        <translation>Questo File è troppo grande (%1 &gt;= %2)</translation>
    </message>
    <message>
        <source>This file is too big for %1.
Do you really want to send this image?
</source>
        <translation>Dimensione file troppo grande per %1.
Sicuro di spedirlo comunque?</translation>
    </message>
    <message>
        <source>This file is too big for %1 of %2 contacts.
Do you really want to send this image?
Some of them probably will not get it.</source>
        <translation>Dimensione file troppo grande per %1 di %2 contatti.
Sei sicuro di voler mandare questa immagine?
Probbabilmente non sarà consegnato a tutti.</translation>
    </message>
    <message>
        <source>Conference with </source>
        <translation>Conferenza con </translation>
    </message>
    <message>
        <source>Chat with </source>
        <translation>Chat con </translation>
    </message>
    <message>
        <source>Chat window will be cleared. Continue?</source>
        <translation>Finestra chat sarà pulita. Continuare?</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Manda</translation>
    </message>
    <message>
        <source>Cannot send message while being offline.</source>
        <translation>Non si può mandare messaggio mentre sei fuori linea.</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annulla</translation>
    </message>
    <message>
        <source>All messages received in this conference will be ignored
from now on. Are you sure you want to leave this conference?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChatWindow</name>
    <message>
        <source>New message received, close window anyway?</source>
        <translation>Ricevuto nuovo messaggio, chiudere comunque?</translation>
    </message>
</context>
<context>
    <name>ChooseDescription</name>
    <message>
        <source>Select description</source>
        <translation>Descrizione</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annulla</translation>
    </message>
</context>
<context>
    <name>ConfigurationWindow</name>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Applica</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>CustomInput</name>
    <message>
        <source>Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Redo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GaduFormater</name>
    <message>
        <source>###IMAGE BLOCKED###</source>
        <translation>###IMAGINE BLOCCATA###</translation>
    </message>
    <message>
        <source>###IMAGE TOO BIG###</source>
        <translation>###IMAGIGINE TROPPO GRANDE###</translation>
    </message>
</context>
<context>
    <name>GaduProtocol</name>
    <message>
        <source>I am busy.</source>
        <translation>Sono occupato.</translation>
    </message>
    <message>
        <source>Unable to connect, server has not been found</source>
        <translation>Impossibile collegarsi, il server non è stato trovato</translation>
    </message>
    <message>
        <source>Unable to connect</source>
        <translation>Collegamento impossibile</translation>
    </message>
    <message>
        <source>Unable to connect, server has returned unknown data</source>
        <translation>Impossibile collegarsi, il server ha restituito i dati sconosciuti</translation>
    </message>
    <message>
        <source>Unable to connect, connection break during reading</source>
        <translation>Impossibile collegarsi, interruzzione del collegamento durante la lettura</translation>
    </message>
    <message>
        <source>Unable to connect, connection break during writing</source>
        <translation>Impossibile collegarsi, interruzione del collegamento durante la scrittura</translation>
    </message>
    <message>
        <source>Unable to connect, incorrect password</source>
        <translation>Impossibile collegarsi, password errata</translation>
    </message>
    <message>
        <source>Unable to connect, error of negotiation TLS</source>
        <translation>Impossibile collegarsi, errore in fase di negoziazione TLS</translation>
    </message>
    <message>
        <source>Connection timeout!</source>
        <translation>Tempo di connessione superato!</translation>
    </message>
    <message>
        <source>Disconnection has occured</source>
        <translation>Disconessione</translation>
    </message>
    <message>
        <source>UIN or password not set!</source>
        <translation>Numero GG o password non mandati!</translation>
    </message>
    <message>
        <source>Please change your email in &quot;Change password / email&quot; window. Leave new password field blank.</source>
        <translation>Cambiare indirizzo e-mail in &quot;Cambia password / email&quot;. Lasciare vuoto il campo nuova password.</translation>
    </message>
    <message>
        <source>Unable to connect, servers are down</source>
        <translation>Impossibile collegarsi, serveri sono fuori linea</translation>
    </message>
    <message>
        <source>Connection will be stopped
Your password is incorrect!</source>
        <translation>Connessione sarà fermato. 
Il tuo password non è corretto!</translation>
    </message>
    <message>
        <source>Too many connection attempts with bad password!</source>
        <translation>Di più conessioni con il password incorretto!</translation>
    </message>
    <message>
        <source>Connection will be stopped
Too many attempts with bad password</source>
        <translation>Connessione sarà fermato
Di più conessioni con il password incorretto</translation>
    </message>
    <message>
        <source>Filtered message too long (%1&gt;=%2)</source>
        <translation>messaggio filtrato troppo lungo (%1&gt;=%2)</translation>
    </message>
    <message>
        <source>Message blocked.</source>
        <translation>Messaggio bloccato.</translation>
    </message>
    <message>
        <source>Messagebox full.</source>
        <translation>Messagebox è pieno.</translation>
    </message>
    <message>
        <source>Message not delivered.</source>
        <translation>Messaggio non fornito.</translation>
    </message>
</context>
<context>
    <name>GroupsManager</name>
    <message>
        <source>All</source>
        <translation>Tutti</translation>
    </message>
</context>
<context>
    <name>Ignored</name>
    <message>
        <source>Manage ignored users</source>
        <translation>Lista contatti ignorati </translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <source>Uin</source>
        <translation>numero GG</translation>
    </message>
    <message>
        <source>This dialog box allows you to manage your ignored contacts.</source>
        <translation>Questa finestra di dialogo permette gestire contatti da igniorare.</translation>
    </message>
    <message>
        <source>Type here the UIN of the person you want to ignore.</source>
        <translation>Metti qui numero GG della persona da igniorare.</translation>
    </message>
    <message>
        <source>Uin:</source>
        <translation>Numero GG:</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
</context>
<context>
    <name>ImageDialog</name>
    <message>
        <source>Images</source>
        <translation>Immagini</translation>
    </message>
</context>
<context>
    <name>Kadu</name>
    <message>
        <source>Configuration</source>
        <translation>Configurazione</translation>
    </message>
    <message>
        <source>Add user</source>
        <translation>Aggiungi il contatto</translation>
    </message>
    <message>
        <source>Kadu: %1</source>
        <translation>Kadu: %1</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Fuori linea</translation>
    </message>
    <message>
        <source>&amp;Exit Kadu</source>
        <translation>&amp;Termina Kadu</translation>
    </message>
    <message>
	<source>Show Pending Messages</source>
	<translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notify about user</source>
        <translation>Notifica contatto</translation>
    </message>
    <message>
        <source>Offline to user</source>
        <translation>Inaccessibile per contatto</translation>
    </message>
    <message>
        <source>Manage &amp;ignored</source>
        <translation>Gestione contatti &amp;ignorati</translation>
    </message>
    <message>
        <source>Personal information</source>
        <translation>Informazioni personali</translation>
    </message>
    <message>
        <source>H&amp;elp</source>
        <translation>Ai&amp;uto</translation>
    </message>
    <message>
        <source>A&amp;bout...</source>
        <translation>In&amp;formazioni su...</translation>
    </message>
    <message>
        <source>&amp;Hide Kadu</source>
        <translation>&amp;Nascondi Kadu</translation>
    </message>
    <message>
        <source>Private</source>
        <translation>Riservato</translation>
    </message>
    <message>
        <source>I&amp;mport / Export userlist</source>
        <translation>I&amp;mport / Export lista contatti</translation>
    </message>
    <message>
        <source>Selected users:
%0will be deleted. Are you sure?</source>
        <translation>Contatti selezionati:
%0saranno eliminati. Vuoi davvero?</translation>
    </message>
    <message>
        <source>Hide description</source>
        <translation>Nascondi descrizione</translation>
    </message>
    <message>
        <source>Search user in directory</source>
        <translation>Cerca contatto nella cartella</translation>
    </message>
    <message>
        <source>Copy description</source>
        <translation>Copia il descrizione</translation>
    </message>
    <message>
        <source>Copy personal info</source>
        <translation>Copia il info personale</translation>
    </message>
    <message>
        <source>Contact: %a[ (%u)]
[First name: %f
][Last name: %r
][Mobile: %m
]</source>
        <translation>Contatto: %a[ (%u)]
[None: %f
][Cognome: %r
][Cellulare: %m
]</translation>
    </message>
    <message>
        <source>Open description link in browser</source>
        <translation>Apri la descrizione link nel WEB browser</translation>
    </message>
    <message>
        <source>Write email message</source>
        <translation>Scrivo email</translation>
    </message>
    <message>
        <source>Search in directory</source>
        <translation>Cerca nella cartella</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Hide offline users</source>
        <translation>Nascondi contatti inattivi</translation>
    </message>
    <message>
        <source>Show offline users</source>
        <translation>Visualizza contatti inattivi</translation>
    </message>
    <message>
        <source>Hide users without description</source>
        <translation>Nascondi contatti senza descrizione</translation>
    </message>
    <message>
        <source>Show users without description</source>
        <translation>Visualizza contatti senza descrizione</translation>
    </message>
    <message>
        <source>Show only online or description buddies</source>
        <translation>Visualizza solo contatti attivi o con la descrizione</translation>
    </message>
    <message>
        <source>Show all users</source>
        <translation>Visualizza tutti contatti</translation>
    </message>
    <message>
        <source>Recent chats...</source>
        <translation>Ultimi chat...</translation>
    </message>
    <message>
        <source>No closed chats found</source>
        <translation>Non trovato i chiusi chat</translation>
    </message>
    <message>
        <source>Contact data</source>
        <translation>Info di contatto</translation>
    </message>
    <message>
        <source>Me</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Online</source>
        <translation type="unfinished">Accessibile</translation>
    </message>
    <message>
        <source>Online (d.)</source>
        <translation type="unfinished">AAccessibile(desc)</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation type="unfinished">Occupato</translation>
    </message>
    <message>
        <source>Busy (d.)</source>
        <translation type="unfinished">Occupato (desc.)</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation type="unfinished">Invisibile</translation>
    </message>
    <message>
        <source>Invisible (d.)</source>
        <translation type="unfinished">Invisibile(desc.)</translation>
    </message>
    <message>
        <source>Offline (d.)</source>
        <translation type="unfinished">Fuori linea(desc)</translation>
    </message>
</context>
<context>
    <name>KaduMainWindow</name>
    <message>
        <source>Create new toolbar</source>
        <translation type="unfinished">Crea nuovo toolbar</translation>
    </message>
</context>
<context>
    <name>KaduTabBar</name>
    <message>
        <source>Add new group</source>
        <translation>Aggiungi nuovo gruppo</translation>
    </message>
    <message>
        <source>Name of new group:</source>
        <translation>Nome del nuovo gruppo:</translation>
    </message>
    <message>
        <source>Add to group %1</source>
        <translation>Aggiungi nel gruppo %1</translation>
    </message>
    <message>
        <source>Move to group %1</source>
        <translation>Riporta nel gruppo %1</translation>
    </message>
</context>
<context>
    <name>KaduTextBrowser</name>
    <message>
        <source>Save image</source>
        <translation>Salva immaggine</translation>
    </message>
    <message>
        <source>File already exists. Overwrite?</source>
        <translation>File esiste. Vuoi davvero sovrascrivere?</translation>
    </message>
    <message>
        <source>Cannot save image: %1</source>
        <translation>Non posso salvare immaggine: %1</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy Link</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save Image</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainConfigurationWindow</name>
    <message>
        <source>None</source>
        <translation>Senza emoticon</translation>
    </message>
    <message>
        <source>Not found</source>
        <translation>Non trovato</translation>
    </message>
    <message>
        <source>Kadu configuration</source>
        <translation>Kadu configurazione</translation>
    </message>
    <message>
        <source>Advenced chat&apos;s look configuration</source>
        <translation>Avvanzato configurazione di finestra chat</translation>
    </message>
    <message>
        <source>Your message</source>
        <translation>Tuo messaggio</translation>
    </message>
    <message>
        <source>Message from Your friend</source>
        <translation>Messaggio del contatto</translation>
    </message>
</context>
<context>
    <name>MessageBox</name>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Sì</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;No</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annulla</translation>
    </message>
</context>
<context>
    <name>ModulesDialog</name>
    <message>
        <source>Manage Modules</source>
        <translation>Gestione Moduli</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Informazioni</translation>
    </message>
    <message>
        <source>Static</source>
        <translation>Statico</translation>
    </message>
    <message>
        <source>Loaded</source>
        <translation>Caricato</translation>
    </message>
    <message>
        <source>Module name</source>
        <translation>Nome del modulo</translation>
    </message>
    <message>
        <source>Module type</source>
        <translation>Tipo del modulo</translation>
    </message>
    <message>
        <source>State</source>
        <translation>Lo stato</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <source>Dynamic</source>
        <translation>Dinamico</translation>
    </message>
    <message>
        <source>Not loaded</source>
        <translation>Non caricato</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versione</translation>
    </message>
    <message>
        <source>&lt;b&gt;Module:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Depends on:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Conflicts with:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Provides:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Author:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Version:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Description:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Modulo:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Dipende da:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Va in conflitto con:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Fornisce:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Autore:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Versione:&lt;/b&gt;&lt;br/&gt;&lt;b&gt;Descrizione:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Hide base modules</source>
        <translation>Nascondo i moduli tipici</translation>
    </message>
    <message>
        <source>&lt;b&gt;Module: &lt;/b&gt;%1&lt;br/&gt;&lt;b&gt;Depends on: &lt;/b&gt;%2&lt;br/&gt;&lt;b&gt;Conflicts with: &lt;/b&gt;%3&lt;br/&gt;&lt;b&gt;Provides: &lt;/b&gt;%4&lt;br/&gt;&lt;b&gt;Author: &lt;/b&gt;%5&lt;br/&gt;&lt;b&gt;Version: &lt;/b&gt;%6&lt;br/&gt;&lt;b&gt;Description: &lt;/b&gt;%7</source>
        <translation>&lt;b&gt;Modulo:&lt;/b&gt;%1&lt;br/&gt;&lt;b&gt;Dipende da:&lt;/b&gt;%2&lt;br/&gt;&lt;b&gt;Va in conflitto con:&lt;/b&gt;%3&lt;br/&gt;&lt;b&gt;Fornisce:&lt;/b&gt;%4&lt;br/&gt;&lt;b&gt;Autore:&lt;/b&gt;%5&lt;br/&gt;&lt;b&gt;Versione:&lt;/b&gt;%6&lt;br/&gt;&lt;b&gt;Descrizione:&lt;/b&gt;%7</translation>
    </message>
    <message>
        <source>This dialog box allows you to manage installed modules. Modules are responsible for numerous vital features like playing sounds or message encryption.
You can load (or unload) them by double-clicking on their names.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ModulesManager</name>
    <message>
        <source>&amp;Manage Modules</source>
        <translation>Gestione &amp;Moduli</translation>
    </message>
    <message>
        <source>Required module %1 was not found</source>
        <translation>Module %1 non trovato</translation>
    </message>
    <message>
        <source>Module %1 is already active</source>
        <translation>Modulo %1 è già attivo</translation>
    </message>
    <message>
        <source>Cannot load %1 module library.:
%2</source>
        <translation>Impossibile caricare modulo libreria %1:
%2</translation>
    </message>
    <message>
        <source>Module %1 cannot be deactivated because it is used now</source>
        <translation>Modulo %1 non può essere disattivato perchè in uso</translation>
    </message>
    <message>
        <source>Module %1 conflicts with: %2</source>
        <translation>Modulo %1 va in conflitto con: %2</translation>
    </message>
    <message>
        <source>Cannot find required functions in module %1.
Maybe it&apos;s not Kadu-compatible Module.</source>
        <translation>Modulo %1 non contiene funzioni richieste.
Possibile incompatibilità con Kadu.</translation>
    </message>
    <message>
        <source>Module initialization routine for %1 failed.</source>
        <translation>Fallita inizializzazione del modulo %1.</translation>
    </message>
</context>
<context>
    <name>OpenChatWith</name>
    <message>
        <source>Open chat with...</source>
        <translation>Apri finestra di Chat con...</translation>
    </message>
    <message>
        <source>Userlist</source>
        <translation>Lista contatti</translation>
    </message>
    <message>
        <source>UIN or nick</source>
        <translation>UIN o nick</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annulla</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
</context>
<context>
    <name>PathListEdit</name>
    <message>
        <source>Select</source>
        <translation>Seleziona</translation>
    </message>
</context>
<context>
    <name>PathListEditWindow</name>
    <message>
        <source>Select paths</source>
        <translation>Seleziona percorsi</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Cambia</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Rimuovi</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annulla</translation>
    </message>
    <message>
        <source>Choose a directory</source>
        <translation>Seleziona cartella</translation>
    </message>
</context>
<context>
    <name>PersonalInfoDialog</name>
    <message>
        <source>Personal Information</source>
        <translation>Dati personali</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Sopranome (Nick)</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Surname</source>
        <translation>Cognome</translation>
    </message>
    <message>
        <source>Gender</source>
        <translation>Sesso</translation>
    </message>
    <message>
        <source>Male</source>
        <translation>Maschio</translation>
    </message>
    <message>
        <source>Female</source>
        <translation>Femmina</translation>
    </message>
    <message>
        <source>Birthyear</source>
        <translation>Anno di nascita</translation>
    </message>
    <message>
        <source>City</source>
        <translation>Città</translation>
    </message>
    <message>
        <source>Family Name</source>
        <translation>Cognome di Famiglia</translation>
    </message>
    <message>
        <source>Family City</source>
        <translation>Città Della Famiglia</translation>
    </message>
    <message>
        <source>This dialog box allows you to manage your personal information, for example your name, surname or age.</source>
        <translation>Questa finestra di dialogo permette di amministrare i tuoi dati personali come nome, cognome, età, sesso.</translation>
    </message>
    <message>
        <source>Your personal information</source>
        <translation>Tuoi dat personali</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Salva</translation>
    </message>
    <message>
        <source>&amp;Reload</source>
        <translation>&amp;Ricarica</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <source>&amp;Search</source>
        <translation>C&amp;erca</translation>
    </message>
    <message>
        <source>&amp;Next results</source>
        <translation>Risultati &amp;successivi </translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Sopranome (Nick)</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Surname</source>
        <translation>Cognome</translation>
    </message>
    <message>
        <source>Gender</source>
        <translation>Sesso</translation>
    </message>
    <message>
        <source>Male</source>
        <translation>Maschio</translation>
    </message>
    <message>
        <source>Female</source>
        <translation>Femmina</translation>
    </message>
    <message>
        <source>Birthyear</source>
        <translation>Anno di nascita</translation>
    </message>
    <message>
        <source>City</source>
        <translation>Città</translation>
    </message>
    <message>
        <source>Uin</source>
        <translation>Numero GG</translation>
    </message>
    <message>
        <source>Search criteria</source>
        <translation>Parametri Ricerca</translation>
    </message>
    <message>
        <source>&amp;Personal data</source>
        <translation>Dati &amp;personali</translation>
    </message>
    <message>
        <source>Search using the personal data typed above (name, nickname)...</source>
        <translation>Cerca usando i dati personali scritti sopra (nome, soprannome)... </translation>
    </message>
    <message>
        <source>&amp;Uin number</source>
        <translation>Numero di &amp;GG</translation>
    </message>
    <message>
        <source>Search for this UIN exclusively</source>
        <translation>Cerca proprio questo numero GG</translation>
    </message>
    <message>
        <source>Only active users</source>
        <translation>Soltanto utenti attivi</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Birth year</source>
        <translation>Anno di nascita</translation>
    </message>
    <message>
        <source>Searching...</source>
        <translation>Ricerca...</translation>
    </message>
    <message>
        <source>Done searching</source>
        <translation>Ricerca completata</translation>
    </message>
    <message>
        <source>from</source>
        <translation>da</translation>
    </message>
    <message>
        <source>to</source>
        <translation>a</translation>
    </message>
    <message>
        <source>There were no results of your search</source>
        <translation>isultato nullo della ricerca</translation>
    </message>
    <message>
        <source>Search user in directory</source>
        <translation>Cerca contatto nella cartella</translation>
    </message>
    <message>
        <source>Clear results</source>
        <translation>Cancella risultati</translation>
    </message>
    <message>
        <source>Add selected user</source>
        <translation>Aggiungi il contatto</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>&amp;Chat</source>
        <translation>&amp;Chat</translation>
    </message>
    <message>
        <source>Cannot search contacts in offline mode</source>
        <translation>Non posso cercare i contatti quando sono fuori line</translation>
    </message>
</context>
<context>
    <name>SelectFile</name>
    <message>
        <source>Insert image</source>
        <translation>Inserisci immagine</translation>
    </message>
    <message>
        <source>Select File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select audio File</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SelectFont</name>
    <message>
        <source>Select</source>
        <translation>Seleziona</translation>
    </message>
</context>
<context>
    <name>SyntaxEditor</name>
    <message>
        <source>Edit</source>
        <translation>Cambiare</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Unable to remove syntax: %1</source>
        <translation>Non posso rimuovi sintasso: %1</translation>
    </message>
</context>
<context>
    <name>SyntaxEditorWindow</name>
    <message>
        <source>Kadu syntax editor</source>
        <translation>Kadu sintasso editor</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>New syntax name</source>
        <translation>Nuovo sintasso nome</translation>
    </message>
    <message>
        <source>Enter new syntax name</source>
        <translation>Scrive il nome di nuovo sintasso</translation>
    </message>
    <message>
        <source>Syntax %1 already exists and cannot be modified</source>
        <translation>Sintasso %1 esiste e non è potuto modificare</translation>
    </message>
    <message>
        <source>Overwrite %1 syntax?</source>
        <translation>Vuoi davvero sovrascrivere syntasso %1?</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>Anteprima</translation>
    </message>
    <message>
        <source>Save as...</source>
        <translation>Salva come...</translation>
    </message>
</context>
<context>
    <name>TokenDialog</name>
    <message>
        <source>Read this code ...</source>
        <translation>Leggi questo codice ...</translation>
    </message>
    <message>
        <source>and type here</source>
        <translation>e risscrivilo qui</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annulla</translation>
    </message>
</context>
<context>
    <name>ToolBar</name>
    <message>
        <source>Delete toolbar</source>
        <translation>Elimina toolbar</translation>
    </message>
    <message>
        <source>Add new button</source>
        <translation>Aggiungi nuovo bottone</translation>
    </message>
    <message>
        <source>Remove toolbar?</source>
        <translation>Rimuovi il toolbar?</translation>
    </message>
    <message>
        <source>No items to add found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show text label</source>
        <translation type="unfinished">Mostra testo</translation>
    </message>
    <message>
        <source>Delete button</source>
        <translation type="unfinished">Elimina bottone</translation>
    </message>
    <message>
        <source>Create new toolbar</source>
        <translation type="unfinished">Crea nuovo toolbar</translation>
    </message>
    <message>
        <source>Block toolbars</source>
        <translation type="unfinished">Blocca toolbars</translation>
    </message>
</context>
<context>
    <name>Updates</name>
    <message>
        <source>The newest Kadu version is %1</source>
        <translation>La versione più recente di Kadu è la %1</translation>
    </message>
</context>
<context>
    <name>UserBox</name>
    <message>
        <source>Hide descriptions</source>
        <translation>Nascondi descrizione</translation>
    </message>
    <message>
        <source>Show descriptions</source>
        <translation>Aggiungi la descrizione</translation>
    </message>
    <message>
        <source>Statuses</source>
        <translation>I status</translation>
    </message>
    <message>
        <source>Nicks, case insensitive</source>
        <translation>Sopranomi (nick),  insensibile al maiuscoli/minuscoli</translation>
    </message>
    <message>
        <source>Nicks</source>
        <translation>Sopranomi (nick)</translation>
    </message>
    <message>
        <source>User management</source>
        <translation type="unfinished">Configurazione degli utenti</translation>
    </message>
</context>
<context>
    <name>UserInfo</name>
    <message>
        <source>User info on %1</source>
        <translation>Info di %1</translation>
    </message>
    <message>
        <source>Uin</source>
        <translation>Numero GG</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Soprannome (Nick)</translation>
    </message>
    <message>
        <source>AltNick</source>
        <translation>Nick Visualizzato</translation>
    </message>
    <message>
        <source>First name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Surname</source>
        <translation>Cognome</translation>
    </message>
    <message>
        <source>Mobile</source>
        <translation>Cell</translation>
    </message>
    <message>
        <source>Address IP and Port</source>
        <translation>Indirizzo IP e Porta</translation>
    </message>
    <message>
        <source>Protocol version</source>
        <translation>Versione protocollo</translation>
    </message>
    <message>
        <source>DNS name</source>
        <translation>Nome DNS </translation>
    </message>
    <message>
        <source>Email</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <source>(Unknown)</source>
        <translation>(Sconosciuto)</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Principale</translation>
    </message>
    <message>
        <source>Block user</source>
        <translation>Blocca contatto</translation>
    </message>
    <message>
        <source>Offline to user</source>
        <translation>Fuori linea per contatto</translation>
    </message>
    <message>
        <source>Notify about status changes</source>
        <translation>Notifica cambiamento di status</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Altro</translation>
    </message>
    <message>
        <source>Add user</source>
        <translation>Aggiungi contatto</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Aggiornamento</translation>
    </message>
    <message>
        <source>Altnick field cannot be empty.</source>
        <translation>Il campo Nick Visualizzato non può essere vuoto.</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <source>This dialog box allows you to view and edit information about the selected contact.</source>
        <translation>Questa finestra di dialogo permette di cambiare informazioni circa il contatto.</translation>
    </message>
    <message>
        <source>Groups</source>
        <translation>Gruppi</translation>
    </message>
    <message>
        <source>Add new group</source>
        <translation>Aggiungi nuovo gruppo</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is prohibited</source>
        <translation>&apos;%1&apos; è proibito</translation>
    </message>
    <message>
        <source>This group already exists!</source>
        <translation>Gruppo esiste già!</translation>
    </message>
    <message>
        <source>Numbers are prohibited</source>
        <translation>I numeri sono proibiti</translation>
    </message>
    <message>
        <source>Change icon</source>
        <translation>Cambia icona</translation>
    </message>
    <message>
        <source>Delete icon</source>
        <translation>Elimina icona</translation>
    </message>
    <message>
        <source>Choose an icon</source>
        <translation>Seleziona icone</translation>
    </message>
    <message>
        <source>Icons (*.png *.xpm *.jpg)</source>
        <translation>Icone (*.png *.xpm *.jpg)</translation>
    </message>
    <message>
        <source>Icon:</source>
        <translation>Icona:</translation>
    </message>
    <message>
        <source>User known as %1 with that UIN is already in userlist.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Online</source>
        <translation>Accessibile</translation>
    </message>
    <message>
        <source>Online (d.)</source>
        <translation>AAccessibile(desc)</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Occupato</translation>
    </message>
    <message>
        <source>Busy (d.)</source>
        <translation>Occupato (desc.)</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation>Invisibile</translation>
    </message>
    <message>
        <source>Invisible (d.)</source>
        <translation>Invisibile(desc.)</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Fuori linea</translation>
    </message>
    <message>
        <source>Offline (d.)</source>
        <translation>Fuori linea(desc)</translation>
    </message>
</context>
<context>
    <name>UserStatus</name>
    <message>
        <source>Online</source>
        <translation>Accessibile</translation>
    </message>
    <message>
        <source>Online (d.)</source>
        <translation>AAccessibile(desc)</translation>
    </message>
    <message>
        <source>Busy</source>
        <translation>Occupato</translation>
    </message>
    <message>
        <source>Busy (d.)</source>
        <translation>Occupato (desc.)</translation>
    </message>
    <message>
        <source>Invisible</source>
        <translation>Invisibile</translation>
    </message>
    <message>
        <source>Invisible (d.)</source>
        <translation>Invisibile(desc.)</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>Fuori linea</translation>
    </message>
    <message>
        <source>Offline (d.)</source>
        <translation>Fuori linea(desc)</translation>
    </message>
    <message>
        <source>Blocking</source>
        <translation>Bloccato</translation>
    </message>
</context>
<context>
    <name>UserlistImportExport</name>
    <message>
        <source>Import / export userlist</source>
        <translation>Import / Export Lista contatti</translation>
    </message>
    <message>
        <source>This dialog box allows you to import and export your buddy list to a server or a file.</source>
        <translation>Questa finestra di dialogo permette di salvare o caricale la tua lista contatti su server Gadu-Gadu, oppure nel file.</translation>
    </message>
    <message>
        <source>Import userlist</source>
        <translation>importa lista contatti</translation>
    </message>
    <message>
        <source>UIN</source>
        <translation>Numero GG</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Nick</translation>
    </message>
    <message>
        <source>Disp. nick</source>
        <translation>Visualizza Nick</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Surname</source>
        <translation>Cognome</translation>
    </message>
    <message>
        <source>Mobile no.</source>
        <translation>Cell no.</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Gruppo</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>E-mail</translation>
    </message>
    <message>
        <source>&amp;Fetch userlist</source>
        <translation>&amp;Carica la lista dei contatti</translation>
    </message>
    <message>
        <source>&amp;Import from file</source>
        <translation>&amp;Importazione dal file</translation>
    </message>
    <message>
        <source>&amp;Save results</source>
        <translation>&amp;Salva i risultati</translation>
    </message>
    <message>
        <source>&amp;Merge results</source>
        <translation>&amp;Unisci risultati</translation>
    </message>
    <message>
        <source>Export userlist</source>
        <translation>Esportazione lista dei contatti</translation>
    </message>
    <message>
        <source>%1 entries will be exported</source>
        <translation>%1 contatti sarnno esportati</translation>
    </message>
    <message>
        <source>Se&amp;nd userlist</source>
        <translation>Ma&amp;nda la lista</translation>
    </message>
    <message>
        <source>&amp;Delete userlist</source>
        <translation>&amp;Cancella la lista contatti</translation>
    </message>
    <message>
        <source>&amp;Export to file</source>
        <translation>Salva in fil&amp;e</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <source>The application encountered an internal error
The import userlist from file was unsuccessful</source>
        <translation>L&apos;applicazione ha generatoun errore interno
L&apos;importazione della lista contatti è fallita</translation>
    </message>
    <message>
        <source>Your userlist has been successfully exported to file</source>
        <translation>La vostra lista contatti è stata salvata con successo in un file</translation>
    </message>
    <message>
        <source>The application encountered an internal error
The export userlist to file was unsuccessful</source>
        <translation>L&apos;applicazione ha generato un errore interno
Salvataggio lista contatti fallito</translation>
    </message>
    <message>
        <source>Your userlist has been successfully exported to server</source>
        <translation>La vostra lista dei contatti è stata esportata con successo sul server GG</translation>
    </message>
    <message>
        <source>The application encountered an internal error
The export was unsuccessful</source>
        <translation>L&apos;applicazione ha incontrato un errore interno
L&apos;esportazione è fallita</translation>
    </message>
    <message>
        <source>Your userlist has been successfully deleted on server</source>
        <translation>La tua lista contatti è stata cancellata con successo su server</translation>
    </message>
    <message>
        <source>The application encountered an internal error
The delete userlist on server was unsuccessful</source>
        <translation>L&apos;applicazione ha generato un errore interno
Cancellazione lista contatti su server GG fallita</translation>
    </message>
    <message>
        <source>Cannot import user list from server in offline mode</source>
        <translation>Non è possibile importare lista utenti da server non attivo </translation>
    </message>
    <message>
        <source>This operation will delete your current user list. Are you sure you want this?</source>
        <translation>Questa operzione cancella lista contatti attuale. Veramente vuoi questo?</translation>
    </message>
    <message>
        <source>Cannot export user list to server in offline mode</source>
        <translation>Non è possibile esportare la lista contatti al server non attivo</translation>
    </message>
    <message>
        <source>Cannot clear user list on server in offline mode</source>
        <translation>Non è possibile cancellare la lista contatti su srever non attivo</translation>
    </message>
    <message>
        <source>File exists. Are you sure you want to overwrite it?</source>
        <translation>File esiste. Vuoi davvero sovrascrivere?</translation>
    </message>
</context>
</TS>
